smartcard

# ``smartcard``

package documentation

Smartcard utility module.

The smartcard utility module provides classes and functions to access smartcards and readers.

__author__ = "gemalto http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Module | `AbstractCardRequest` | AbstractCardRequest class.
Module | `ATR` | ATR class managing some of the Answer To Reset content.
Module | `Card` | Card class.
Module | `CardConnection` | The CardConnection abstract class manages connections with a card and apdu transmission.
Module | `CardConnectionDecorator` | The CardConnectionDecorator is a Decorator around the CardConnection abstract class, and allows dynamic addition of features to the CardConnection, e.g. implementing a secure channel..
Module | `CardConnectionEvent` | The CardConnectionEvent is sent to CardConnectionObserver objects when a CardConnection event occurs.
Module | `CardConnectionObserver` | CardConnectionObserver interface.
Module | `CardMonitoring` | Smart card insertion/removal monitoring classes.
Module | `CardNames` | Card Names class
Module | `CardRequest` | Smartcard CardRequest.
Module | `CardService` | Card service abstract class.
Module | `CardType` | Abstract CarType.
Module | `ClassLoader` | ClassLoader allows you to load modules from packages without hard-coding their class names in code; instead, they might be specified in a configuration file, as command-line parameters, or within an interface.
Module | `Exceptions` | Smartcard module exceptions.
Module | `ExclusiveConnectCardConnection` | CardConnectionDecorator that provides exclusive use of a card.
Module | `ExclusiveTransmitCardConnection` | Sample CardConnectionDecorator that provides exclusive transmit()
Module | `guid` | smartcard.guid
Module | `Observer` | from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
Module | `PassThruCardService` | Card service abstract class.
Package | `pcsc` | No package docstring; 7/7 modules documented
Package | `pyro` | pyro (remote python) utility module.
Package | `reader` | No package docstring; 3/3 modules documented
Module | `ReaderMonitoring` | Smart card reader monitoring classes.
Package | `scard` | No package docstring; 1/1 module documented
Package | `sw` | smartcard.sw module for status word error checking.
Module | `Synchronization` | from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
Module | `System` | Smartcard system utility functions and classes.
Module | `ulist` | ulist is a subclass of list where items cannot appear twice in the list.
Package | `util` | smartcard.util package
Package | `wx` | wxpython smartcard utility module.

From `__init__.py`:

Class | `Session` | The Session object enables programmers to transmit APDU to smartcards.
Function | `listReaders` | Returns the list of smartcard readers.

def listReaders():

Returns the list of smartcard readers.

Deprecated - Use `smartcard.System.readers()` instead.